@@ -11,7 +11,7 @@ use Test::More;
 
 # VERSION
 
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 
 # AUTHORITY
 
@@ -79,6 +79,13 @@ sub standard {
   return $self;
 }
 
+sub subtests {
+  my ($self) = @_;
+
+  # approximating the v1 API subtests
+  return $self;
+}
+
 sub package {
   my ($self) = @_;
 
@@ -231,7 +238,7 @@ Test Automation for Perl 5
 
 =head1 VERSION
 
-0.13
+0.14
 
 =cut
 
@@ -246,6 +253,8 @@ Test Automation for Perl 5
     't/Test_Auto.t'
   );
 
+  # ...
+
   # =synopsis
   #
   # use Path::Find 'path';
@@ -294,7 +303,7 @@ powerful hooks into the framework for manual testing.
 
     ok my $result = $tryable->result, 'result ok';
 
-    # must return truthy to cont
+    # must return truthy to continue
     $result;
   });
 
@@ -317,7 +326,7 @@ exceptions simple, for example:
     ok my $result = $tryable->result, 'result ok';
     ok $result->isa('Path::Find::Error'), 'exception caught';
 
-    # must return truthy to cont
+    # must return truthy to continue
     $result;
   });
 
@@ -333,7 +342,7 @@ result as a L<Venus::Try> object. The first argument is the example ID (or
 
     ok my $result = $tryable->result, 'result ok';
 
-    # must return truthy to cont
+    # must return truthy to continue
     $result;
   });
 
@@ -348,7 +357,7 @@ as a L<Venus::Try> object, for example:
 
     ok my $result = $tryable->result, 'result ok';
 
-    # must return truthy to cont
+    # must return truthy to continue
     $result;
   });
 
@@ -358,47 +367,47 @@ reusability and reduces the need for complicated state and test setup.
 
 =head1 SPECIFICATION
 
-  # Since 0.13
+  # Version 0.13+
 
   # [required]
 
   =name
   =abstract
-  =tagline
   =includes
   =synopsis
   =description
 
   # [optional]
 
+  =tagline
   =libraries
   =inherits
   =integrates
 
-  # [repeatable; optional]
+  # [optional; repeatable]
 
   =feature $name
   =example $name
 
-  # [repeatable; optional]
+  # [optional; repeatable]
 
   =attribute $name
   =signature $name
   =example-$number $name # [repeatable]
 
-  # [repeatable; optional]
+  # [optional; repeatable]
 
   =method $name
   =signature $name
   =example-$number $name # [repeatable]
 
-  # [repeatable; optional]
+  # [optional; repeatable]
 
   =function $name
   =signature $name
   =example-$number $name # [repeatable]
 
-  # [repeatable; optional]
+  # [optional; repeatable]
 
   =routine $name
   =signature $name
@@ -406,8 +415,8 @@ reusability and reduces the need for complicated state and test setup.
 
 The specification is designed to accommodate typical package declarations. It
 is used by the parser to provide the content used in test automation and
-document generation. B<Note:> When code blocks are evaluated I<"redefined">
-warnings are now automatically disabled.
+document generation. B<Note:> When code blocks are evaluated, the
+I<"redefined"> warnings are now automatically disabled.
 
 =head2 name
 
@@ -417,6 +426,8 @@ warnings are now automatically disabled.
 
   =cut
 
+  $test->for('name');
+
 The C<name> block should contain the package name. This is tested for
 loadability.
 
@@ -428,6 +439,8 @@ loadability.
 
   =cut
 
+  $test->for('tagline');
+
 The C<tagline> block should contain a tagline for the package. This is optional
 but if present is concatenated with the C<name> during POD generation.
 
@@ -439,6 +452,8 @@ but if present is concatenated with the C<name> during POD generation.
 
   =cut
 
+  $test->for('abstract');
+
 The C<abstract> block should contain a subtitle describing the package. This is
 tested for existence.
 
@@ -453,6 +468,8 @@ tested for existence.
 
   =cut
 
+  $test->for('includes');
+
 The C<includes> block should contain a list of C<function>, C<method>, and/or
 C<routine> names in the format of C<$type: $name>. Empty lines are ignored.
 This is tested for existence. Each function, method, and/or routine is tested
@@ -470,6 +487,14 @@ exists.
 
   =cut
 
+  $test->for('synopsis', sub {
+    my ($tryable) = @_;
+    my $result = $tryable->result;
+
+    # must return truthy to continue
+    $result
+  });
+
 The C<synopsis> block should contain the normative usage of the package. This
 is tested for existence. This block should be written in a way that allows it
 to be evaled successfully and should return a value.
@@ -483,6 +508,8 @@ to be evaled successfully and should return a value.
 
   =cut
 
+  $test->for('description');
+
 The C<description> block should contain a thorough explanation of the purpose
 of the package. This is tested for existence.
 
@@ -495,6 +522,8 @@ of the package. This is tested for existence.
 
   =cut
 
+  $test->for('libraries');
+
 The C<libraries> block should contain a list of packages, each of which is
 itself a L<Type::Library>. These packages are tested for loadability, and to
 ensure they are type library classes.
@@ -507,6 +536,8 @@ ensure they are type library classes.
 
   =cut
 
+  $test->for('inherits');
+
 The C<inherits> block should contain a list of parent packages. These packages
 are tested for loadability.
 
@@ -519,6 +550,8 @@ are tested for loadability.
 
   =cut
 
+  $test->for('integrates');
+
 The C<integrates> block should contain a list of packages that are involved in
 the behavior of the main package. These packages are not automatically tested.
 
@@ -540,6 +573,13 @@ the behavior of the main package. These packages are not automatically tested.
 
   =cut
 
+  $test->for('example', 'export-path-make', sub {
+    my ($tryable) = @_;
+    my $result = $tryable->result;
+
+    # must return truthy to continue
+    $result
+  });
 
 There are situation where a package can be configured in different ways,
 especially where it exists without functions, methods or routines for the
@@ -563,12 +603,24 @@ Each feature is tested and must be recognized to exist by the main package.
 
   cwd(Str $path) : (Object)
 
+  =cut
+
   =example-1 cwd
 
   # given: synopsis
 
   my $cwd = $path->cwd;
 
+  =cut
+
+  $test->for('example', 1, 'cwd', sub {
+    my ($tryable) = @_;
+    my $result = $tryable->result;
+
+    # must return truthy to continue
+    $result
+  });
+
   =example-2 cwd
 
   # given: synopsis
@@ -577,6 +629,14 @@ Each feature is tested and must be recognized to exist by the main package.
 
   =cut
 
+  $test->for('example', 2, 'cwd', sub {
+    my ($tryable) = @_;
+    my $result = $tryable->result;
+
+    # must return truthy to continue
+    $result
+  });
+
 Describing an attribute requires at least three blocks, i.e. C<attribute
 $name>, C<signature $name>, and C<example-1 $name>. The C<attribute> block
 should contain a description of the attribute and its purpose. The C<signature>
@@ -600,12 +660,24 @@ is tested and must be recognized to exist by the main package.
 
   children() : [Object]
 
+  =cut
+
   =example-1 children
 
   # given: synopsis
 
   my $children = $path->children;
 
+  =cut
+
+  $test->for('example', 1, 'children', sub {
+    my ($tryable) = @_;
+    my $result = $tryable->result;
+
+    # must return truthy to continue
+    $result
+  });
+
   =example-2 children
 
   # given: synopsis
@@ -614,6 +686,14 @@ is tested and must be recognized to exist by the main package.
 
   =cut
 
+  $test->for('example', 2, 'children', sub {
+    my ($tryable) = @_;
+    my $result = $tryable->result;
+
+    # must return truthy to continue
+    $result
+  });
+
 Describing a method requires at least three blocks, i.e. C<method $name>,
 C<signature $name>, and C<example-1 $name>. The C<method> block should contain
 a description of the method and its purpose. The C<signature> block should
@@ -637,6 +717,8 @@ must be recognized to exist by the main package.
 
   path() : Object
 
+  =cut
+
   =example-1 path
 
   package Test::Path::Find;
@@ -647,6 +729,14 @@ must be recognized to exist by the main package.
 
   =cut
 
+  $test->for('example', 1, 'path', sub {
+    my ($tryable) = @_;
+    my $result = $tryable->result;
+
+    # must return truthy to continue
+    $result
+  });
+
 Describing a function requires at least three blocks, i.e. C<function $name>,
 C<signature $name>, and C<example-1 $name>. The C<function> block should
 contain a description of the function and its purpose. The C<signature> block
@@ -670,12 +760,24 @@ is tested and must be recognized to exist by the main package.
 
   algorithms() : Object
 
+  =cut
+
   =example-1 algorithms
 
   # given: synopsis
 
   $path->algorithms
 
+  =cut
+
+  $test->for('example', 1, 'algorithms', sub {
+    my ($tryable) = @_;
+    my $result = $tryable->result;
+
+    # must return truthy to continue
+    $result
+  });
+
   =example-2 algorithms
 
   package Test::Path::Find;
@@ -686,6 +788,14 @@ is tested and must be recognized to exist by the main package.
 
   =cut
 
+  $test->for('example', 2, 'algorithms', sub {
+    my ($tryable) = @_;
+    my $result = $tryable->result;
+
+    # must return truthy to continue
+    $result
+  });
+
 Typically, a Perl subroutine is declared as a function or a method. Rarely, but
 sometimes necessary, you will need to describe a subroutine where the invocant
 is either a class or class instance. Describing a routine requires at least
@@ -836,7 +946,7 @@ I<Since C<0.13>>
 
   # given: synopsis
 
-  my $data = $test->for('synosis');
+  my $data = $test->for('synopsis');
 
   # bless({value => 't/Test_Auto.t'}, 'Test::Auto')
 
